# qtneat
Set the Qt frameless titlebar/theme easily

There is qtmodern, qtawesome, i chose the word "<b>neat</b>".

Tell me that naming is nice.

I'll make this usable not only for PyQt5, but also for PyQt6 and PySide6.

## Requirements
* PyQt5 >= 5.8

## Setup
`python -m pip install qtneat`
